//--------------------------------------------------------------------------  DistributionOverStates_programs
// This code contains two programs called by DistributionOverStates.do
// This code uses BGH's routine meandifs.
//
// Last Revision: 09/04/2015
//-------------------------------------------------------------------------------------------------------------------------------




	
	
//---------------------------------------------------------------------------------------------
// This programs obtains the distribution over states (earnings / welfare participation).
//---------------------------------------------------------------------------------------------
	capture program drop DistributionOverStates_P
	capture program define DistributionOverStates_P
		args dtain  dtaout 
		

		
		//---------------------------------------------------
		qui use "`dtain'", clear	
		//---------------------------------------------------
		// inverse propensity score weights.
		//---------------------------------------------------
		qui logit e $pscorevars, asis
		qui predict double pscore                                      
		qui gen double pscorewt = e/pscore + (1-e)/(1-pscore)
		//---------------------------------------------------
		// Reshape long to have a data set with quartely probabilities
		//---------------------------------------------------
		local nmv = 0
		if "$marginalvars"=="p0N p1N p2N p0P p1P p2P" { 
			local nmv = 6
			keep p0N* p1N* p2N* p0P* p1P* p2P*  pscorewt e id included* $pscorevars
			qui reshape long p0N@ p1N@ p2N@ p0P@ p1P@ p2P@ included@, i(id) j(q)
		}
		if "$marginalvars"=="p0N p1N p2N p3N p0P p1P p2P p3P" {
			local nmv = 8
			keep p0N* p1N* p2N* p3N* p0P* p1P* p2P* p3P* pscorewt e id included* 
			qui reshape long p0N@ p1N@ p2N@ p3N@ p0P@ p1P@ p2P@ p3P@ included@, i(id) j(q)
		}
		//---------------------------------------------------
		// Get coefficient of treatment indicator in a regression
		// of included on the treatment indicator and the $pscorevars (reported in the paper)
		//---------------------------------------------------
		capture assert included==1
		if _rc~=0 & "$marginalvars"=="p0N p1N p2N p0P p1P p2P" {
			di ""
			di ""
			di " ====================================== Impact of Treatment on Included"
			di " (result referenced in footnote 24 of the paper)"
			qui reg included e  $pscorevars,  cluster(id)
			di "Using linear regression the coefficient of the treatment indicator is =" _b[e]
			qui logit included e  $pscorevars,  cluster(id)
			di "Using logit model the coefficient of the treatment indicator is =" _b[e]
			drop $pscorevars
		}
		
		//---------------------------------------------------
		// Estimate distributions over observed states for control and for treatment groups
		// Note: Account for the fact that you may exclude some quarters from the computations
		// estimated probability - among controls - of being in subcollection x (weighted using the prop score)
		// estimated probability - among treatment - of being in subcollection x (weighted using the prop score)
		//---------------------------------------------------
		// Un-adjusted Means and Difference in Means
		qui sum included 		if e==0
		qui gen p = r(mean) 	if e==0
		qui sum included 		if e==1
		qui replace p = r(mean) if e==1
		// E[YD|T]/E[D|T] where D=1 if included, T=1 if JF and Y=p's
		foreach var of varlist $marginalvars {
			qui gen `var'_orig = `var'
			qui replace `var' = `var'_orig/p
		}
		qui meandifs $marginalvars, by(e) 
		matrix define TabUt = r(table) // store results	
				
		qui sum $marginalvars if e==0
		local nobsC = r(N)
		qui sum $marginalvars if e==1
		local nobsT = r(N)

		// Adjusted Means and Difference in Means"
		drop p
		qui sum included 	[aw=pscorewt]	if e==0
		qui gen p = r(mean) 	if e==0
		qui sum included 	[aw=pscorewt]	if e==1
		qui replace p = r(mean) if e==1
		// E[YD|T]/E[D|T] where D=1 if in x subcollection, T=1 if JF and Y=p's
		foreach var of varlist $marginalvars {
			qui replace `var' = `var'_orig
			qui replace `var' = `var'_orig/p
		}
		drop *_orig
		qui meandifs $marginalvars [aw=pscorewt], by(e) 
		matrix define TabAt = r(table) // store results
		//----------------------------------------------------------------------------------
		// Write out results
		//----------------------------------------------------------------------------------
		matrix define TabAll = J(`nmv',6,0)
		local l = (1-1)*`nmv'+1
		local u = 1*`nmv'
		matrix define b = TabUt[1,`l'..`u']'
		matrix define TabAll = b
		forvalues j=2(1)3 {
				local l = (`j'-1)*`nmv'+1
				local u = `j'*`nmv'
				matrix define b = TabUt[1,`l'..`u']'
				matrix define TabAll = (TabAll,b)
		}
		forvalues j=1(1)3 {
				local l = (`j'-1)*`nmv'+1
				local u = `j'*`nmv'
				matrix define b = TabAt[1,`l'..`u']'
				matrix define TabAll = (TabAll,b)
		}		
		di ""
		di ""
		di "====================================== Distribution over States"
		matrix colnames TabAll = "T_U" "C_U" "Diff" "T_A" "C_A" "Diff"
		matrix list TabAll, noheader format(%6.3f)
		*di "Not rounded:"
		*matrix list TabAll
		di ""
		di "The number of observations  used for the Control-frequencies is " `nobsC' 
		di "The number of observations  used for the Treatment-frequencies is " `nobsT'		
		
		//-----------------------------------------------------------------------------------
		// Save to .dta file for later merge to the bootstrapped p's .dta file
		//-----------------------------------------------------------------------------------
		qui keep if _n==1
		local col = 0
		foreach var of varlist $marginalvars {
			local col = `col'+1
			qui gen `var'_t1 = TabAt[1,`col'] 
		}
		foreach var of varlist $marginalvars {
			local col = `col'+1
			qui gen `var'_c1 = TabAt[1,`col'] 
		}
		foreach var of varlist $marginalvars {
			qui gen `var'_diff1 = `var'_t1-`var'_c1
		}
		keep *_t1 *c1 *_diff1
		qui save "`dtaout'", replace
		

	end

	
	
	
	
	
	
	
	
//----------------------------------------------------------------------------------------------
// This program boostraps the data and uses it to compute SEs for the distribution over observable states.
// The boostrapped distributions are saved into a .dta file for later processing.
//----------------------------------------------------------------------------------------------
capture program drop DistributionOverStates_SE
capture program define DistributionOverStates_SE
	args nboots dtafile  
	//---------------------------------------------------
	di ""
	di ""
	di "=========================================== Bootstrapping with replacement to obtain SE"
	forvalues r=1(1)`nboots' {
		forvalues i=0(1)10 {
			if `r'==`i'*100 {
				di "- working on bootstrapped sample `r' "
			}
		}
		if `r'==1 {
			di "- working on bootstrapped sample `r' (boostrapping takes time ...)"
		}
		preserve
			//---------------------------------------------------
			// Draw a random sample from existing data
			//---------------------------------------------------
			rename id pufid
			qui bsample, cluster(pufid) idcluster(id)
			//---------------------------------------------------
			//Now executing code necessary for pscore model and inverse propensity score weighting (IPW) stuff 
			//---------------------------------------------------
			qui logit e $pscorevars, asis
			qui predict double pscore                                      
			qui gen double pscorewt = e/pscore + (1-e)/(1-pscore)
			//---------------------------------------------------
			// Reshape long to have a data set with quartely marginal probabilities
			//---------------------------------------------------
			if "$marginalvars"=="p0N p1N p2N p0P p1P p2P" { 
				local nmv = 6
				keep p0N* p1N* p2N* p0P* p1P* p2P*  pscorewt e id included*
				qui reshape long p0N@ p1N@ p2N@ p0P@ p1P@ p2P@  included@, i(id) j(q)
			}
			if "$marginalvars"=="p0N p1N p2N p3N p0P p1P p2P p3P" { 
				local nmv = 8
				keep p0N* p1N* p2N* p3N* p0P* p1P* p2P* p3P* pscorewt e id included*
				qui reshape long p0N@ p1N@ p2N@ p3N@ p0P@ p1P@ p2P@ p3P@ included@, i(id) j(q)
			}
			//---------------------------------------------------
			// Estimate marginal distributions for control and for treatment groups
			//---------------------------------------------------
			foreach var of varlist $marginalvars {
				qui gen temp = `var'				
				if 1==1 { // if you want to do the conditional reweighting
					qui sum included 	[aw=pscorewt]	if e==0
					qui gen p = r(mean) 			if e==0
					qui sum included 	[aw=pscorewt]	if e==1
					qui replace p = r(mean) 		if e==1
					qui replace temp = `var'/p
				}
				qui sum temp [aw=pscorewt] if e==1
				local meant = r(mean)
				qui sum temp [aw=pscorewt] if e==0
				local meanc = r(mean)
				matrix define diff = `meant'-`meanc'
				matrix define meant = `meant'
				matrix define meanc = `meanc'
				if `r'==1 {
					matrix define `var'_t  = meant // inizialize the vector
					matrix define `var'_c  = meanc // inizialize the vector
					matrix define `var'_diff  = diff // inizialize the vector
				}
				else {
					matrix define `var'_t  = `var'_t\meant // append
					matrix define `var'_c  = `var'_c\meanc // append
					matrix define `var'_diff = `var'_diff\diff // append
				}
				drop temp
				drop p
			}
		restore // end of bootstrap	
	} // end of all bootstraps
	//----------------------------------------------------------------------------------------------
	// Use the differences in means for each bootstrapped sample 
	// to compute SEs of the difference in the proportions  between control and treatment group.
	// Boostrapped data is save for later processing in Matlab.
	//----------------------------------------------------------------------------------------------
	matrix define TabSE = J(`nmv',3,0)
	local nv = 0
	foreach var in  $marginalvars {
		local nv = `nv'+1
		di ""
		qui svmat `var'_diff, names(`var'_diff)
		qui svmat `var'_t, names(`var'_t)
		qui sum `var'_t1
		matrix define TabSE[`nv',1] = r(sd)
		qui svmat `var'_c, names(`var'_c)
		qui sum `var'_c1
		matrix define TabSE[`nv',2] = r(sd)
		qui sum `var'_diff
		matrix define TabSE[`nv',3] = r(sd)
	}		
	di ""
	di ""
	di "====================================== Distribution over States"
	di "The boostrapped SEs for the adjusted distributions and the difference are in the last 3 cols."
	matrix define TabAll2 = (TabAll,TabSE)
	matrix colnames TabAll2 = "T_U" "C_U" "Diff" "T_A" "C_A" "Diff" "T_A_SE" "C_A_SE" "Diff_SE"
	matrix list TabAll2, noheader format(%6.3f)
	//-----------------------------------------------------------------------
	qui keep if _n<=`nboots'
	keep *_t1 *c1 *_diff1
	qui save "`dtafile'", replace
	clear
end









