//---------------------------------------------------------------- kt_JF_createAFDCrules
// This code produces a data set of welfare policy parameters used in subsequent parts of the code.
// 
// This code has five parts:
// 	PART 1: sets up data set
// 	PART 2: records welfare policy paremeters
// 	PART 3: stores the information into a .dta file
// 
// This code take no inputs.
// 
// This code outputs:
// 	1. A .dta file with policy parameters
// 
// Last Revision: 09/01/2015
//-------------------------------------------------------------------------------------------------------------------------------
args outdta





//------------------------------------------------ PART 1  ------------------------------------------------------
// Sets up data set for the relevant period, 1996 to 2000
//---------------------------------------------------------------------------------------------------------------
	clear
	set obs 5 // years from 1996 to 2000 included
	qui gen year = 1996
	qui replace year = year+_n-1 if _n>1

	expand 12 // 12 AU sizes
	qui gen size = . 
	bys year: replace size = _n



//------------------------------------------------ PART 2  ------------------------------------------------------
// Declaring welfare policy paramters
//---------------------------------------------------------------------------------------------------------------
	//------------------------------------------------------------------
	// tao0 is a multiplier of poverty level used to determine eligibility under CT's AFDC
	// tao1 is the fraction of the gap b/w the payment standard (MSBN) and the AU's resources 
	//      paid out as welfare benefits ("fill the gap" parameter)
	// tao2 is the baseline proportional earning disregard
	//------------------------------------------------------------------
	local tao0 = 1.85
	local tao1 = 0.73
	local tao2 = 1/3

	//------------------------------------------------------------------
	// b0 is maximum benefit payable (MAP)
	// b1 is the payment standard (MSBN)
	// F3 is the FPL
	//
	// Notes:
	// -	b0 is the same for all the years, whether with or without 
	// 		accounting for the case's receipt of housing subsidies (HS) 
	// - 	in CT it is the case that b0 = b1 * tao1 
	//------------------------------------------------------------------
	qui gen b0_yhs = .
	qui gen b0_nhs = .

	qui gen b1_yhs = .
	qui gen b1_nhs = .

	qui gen F3 = .
	qui gen F3incr = .

	qui replace b0_yhs = 306 if size==1 // AU receives HS
	qui replace b0_yhs = 407 if size==2
	qui replace b0_yhs = 500 if size==3
	qui replace b0_yhs = 588 if size==4
	qui replace b0_yhs = 672 if size==5
	qui replace b0_yhs = 761 if size==6
	qui replace b0_yhs = 858 if size==7
	qui replace b0_yhs = 948 if size==8
	qui replace b0_yhs = 1027 if size==9
	qui replace b0_yhs = 1122 if size==10
	qui replace b0_yhs = 1170 if size==11
	qui replace b0_yhs = 1282 if size==12

	qui replace b0_nhs = 333 if size==1 // AU does not receive HS
	qui replace b0_nhs = 443 if size==2
	qui replace b0_nhs = 543 if size==3
	qui replace b0_nhs = 639 if size==4
	qui replace b0_nhs = 731 if size==5
	qui replace b0_nhs = 827 if size==6
	qui replace b0_nhs = 933 if size==7
	qui replace b0_nhs = 1031 if size==8
	qui replace b0_nhs = 1117 if size==9
	qui replace b0_nhs = 1221 if size==10
	qui replace b0_nhs = 1272 if size==11
	qui replace b0_nhs = 1394 if size==12

	qui replace b1_yhs = b0_yhs/`tao1' // because b0 = b1 * tao1 
	qui replace b1_nhs = b0_nhs/`tao1'


	qui replace F3 = 7740 if year==1996
	qui replace F3 = 7890 if year==1997
	qui replace F3 = 8050 if year==1998
	qui replace F3 = 8240 if year==1999
	qui replace F3 = 8350 if year==2000

	qui replace F3incr = 2620 if year==1996
	qui replace F3incr = 2720 if year==1997
	qui replace F3incr = 2800 if year==1998
	qui replace F3incr = 2820 if year==1999
	qui replace F3incr = 2900 if year==2000

	forvalues s=2(1)12 {
		qui replace F3 = F3 + F3incr*(`s'-1) if size==`s'
	}
	qui replace F3 = round(F3/12,1) // b/c we want it monthly



//------------------------------------------------ PART 3  ------------------------------------------------------
// Save for later access
//---------------------------------------------------------------------------------------------------------------
sort year size
qui save "`outdta'", replace













