// ---------------------------------------------------------------------------------------------MeanPostRAOutcomes_programs
// This code contains two programs called by MeanPostRAOutcomes.do
//
// Last Revision: 08/31/2015
//-------------------------------------------------------------------------------------------------------------------------------



	
//--------------------------------------------------------------------------------	
// Creates the following variables:
//	ernqa17			= earning amount in quarter
//	anyernqa17		= indicator for whether earnings in quarter is positive 
//	fqebelow1FPL	= indicator for whether earnings in quarter is below 1*FPL
//	fqebelow3FPL	= indicator for whether earnings in quarter is below 3*FPL
//	fqonAFDC		= indicator for whether on welfare assistance in quarter
//	fqonAFDCzeroern = indicator for whether with earnings=0 and on welfare assistance (at least 1 month out of the quarter)
//--------------------------------------------------------------------------------	
	capture program drop create_vars_in_table
	capture program define create_vars_in_table
		args fq lq 
		//-----------------------------------------------------
		// fraction of quarters with earning below quartely FPL
		// fraction of quarters with earning below quartely FPL/3
		//-----------------------------------------------------
		qui gen n_a = .
		qui gen n_b = .
		qui gen nn = .
		forvalues y=1996(1)1998 {
			forvalues s=1(1)5 {
				//-----------------------------------------
				// this is the size to use for the FPL = 
				// `s' means exactly the size in the data, 
				// `s'+1 means the next size up.
				//-----------------------------------------
				local ss = `s' +1
				qui sum F3_`ss' if year==`y'
				qui replace n_a = 1  if size==`s'&year==`y'&earnq<=3*r(min) 
				qui replace n_b = 1  if size==`s'&year==`y'&earnq<=r(min) 
				qui replace nn  = 1  if size==`s'&year==`y' // just to make sure that every person's quater is tagged
			}
		}
		qui bys id: egen snn = sum(nn) 
		assert snn==3*(`lq'-`fq'+1)
		qui bys id: egen fqebelow3FPL = sum(n_a)
		qui bys id: egen fqebelow1FPL = sum(n_b)
		qui replace fqebelow3FPL = fqebelow3FPL/(`lq'-`fq'+1) 
		qui replace fqebelow1FPL = fqebelow1FPL/(`lq'-`fq'+1) 
		qui replace fqebelow3FPL = fqebelow3FPL/3 // simply because the data is monthly so each quater earnings appears 3 times
		qui replace fqebelow1FPL = fqebelow1FPL/3 // simply because the data is monthly so each quater earnings appears 3 times
		drop n_a
		drop n_b	
		drop nn
		drop snn	
		//-----------------------------------------------------
		// fraction of quarters on welfare (count a quarter as on welfare as long as at least one month on)
		//-----------------------------------------------------
		qui gen n = 0
		forvalues q=`fq'(1)`lq' {
			qui replace n = n+1 if anyadcq`q'==1
		}	
		qui gen fqonAFDC = n/(`lq'-`fq'+1) 
		assert n~=.
		//-----------------------------------------------------
		// fraction of quarters on welfare (count a quarter as long as at least one month on) and not working
		//-----------------------------------------------------
		qui replace n = 0
		forvalues q=`fq'(1)`lq' {
			qui replace n = n+1 if anyadcq`q'==1&ernq`q'==0
		}	
		qui gen fqonAFDCzeroern = n/(`lq'-`fq'+1) 
		drop n
		//------------- try and replicate 
		capture confirm variable ernqa`fq'`lq'
		if _rc==0 {
			rename ernqa`fq'`lq' ernqa`fq'`lq'_orig
			rename anyernqa`fq'`lq' anyernqa`fq'`lq'_orig
		}
		qui gen ernqa`fq'`lq' = 0
		qui gen anyernqa`fq'`lq' = 0
		forvalues q=`fq'(1)`lq' {
			qui replace ernqa`fq'`lq' = ernqa`fq'`lq' +ernq`q' 
			qui replace anyernqa`fq'`lq' = anyernqa`fq'`lq' + 1 if ernq`q'>0
		}
		qui replace ernqa`fq'`lq' = (ernqa`fq'`lq')/(`lq'-`fq'+1) // average of q. earnings
		qui replace anyernqa`fq'`lq' = (anyernqa`fq'`lq')/(`lq'-`fq'+1) // average of q. earnings
		
		capture confirm variable ernqa`fq'`lq'_orig
		if _rc==0 {
			assert ernqa`fq'`lq'_orig==ernqa`fq'`lq'
			drop ernqa`fq'`lq'_orig
			assert anyernqa`fq'`lq'_orig==anyernqa`fq'`lq'
			drop anyernqa`fq'`lq'_orig
		}
	end
	
	

	
	
	
	
	
	

	
	
	
	
	
	
	
	
//--------------------------------------------------------------------------------
// Obtain variable avgernqifon = average earnings Q1-Q7 limitedly to quarters 
// when on welfare assistance for at least one month
//--------------------------------------------------------------------------------
	capture program drop create_vars_in_table_needpscore
	capture program define create_vars_in_table_needpscore
		args fq lq pscore 
		//-----------------------------------------------------
		qui gen ee = 0
		qui gen n = 0
		forvalues q=`fq'(1)`lq' {
			qui replace ee = ee+ernq`q' if anyadcq`q'==1
			qui replace n = n+1         if anyadcq`q'==1
		}
		capture drop avgernqifon
		qui gen avgernqifon = ee/(`lq'-`fq'+1) 		// it is zero if the person never was on AFDC in the quarters considered
		qui gen ind = n/(`lq'-`fq'+1)               // within a person fraction of quarters contributing to the average
		//-----------------------------------------------------
		qui sum ind [aw=`pscore']  	if e==0 
		qui gen p = r(mean) 		if e==0 
		qui sum ind [aw=`pscore']  	if e==1 
		qui replace p = r(mean) 	if e==1 
		qui replace avgernqifon = avgernqifon/p 
		//-----------------------------------------------------
		drop ind
		drop p
		drop n
		drop ee	
	end
	
	
	
	
	
	


//--------------------------------------------------------------------------------
//--------------------------------------------------------------------------------
	capture program drop gettable
	capture program define gettable
		args wv g
		//-------------------------------------------------------------------
		// Compute adjusted means of the variables appearing in the Table.
		// We use BGH's meandiff function (the unadjusted means for Jobs First group: eqname t;
		// those for AFDC group: eqname c' the differences: eqname d).
		//-------------------------------------------------------------------
		qui meandifs $tabvars [aw=`wv'], by(e) // Adjusted Means
		matrix define Tab= r(table)
		forvalues j=1(1)3 {
			local l = (`j'-1)*$nvp+1
			local u = `j'*$nvp
			matrix define b`j' = Tab[1,`l'..`u']
		}		
		//-------------------------------------------------------------------
		// Store the information in a matrix, for convenience
		//-------------------------------------------------------------------	
		local suffix = "all"
		if "`g'"~="all" {
			local suffix = "g`g'"
		}
		matrix define m_`suffix' = (b1\b2\b3)'
		matrix colnames m_`suffix' = Tmean Cmean ADiff 		
		di "Sample sizes by treatment group:"
		tab e  // sample sizes
	end
	
	
	

	
	
	
	
	
		